/*
 *  Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License
 */
/*
 * @file        native-mainloop.h
 * @author      Kyungwook Tak (k.tak@samsung.com)
 * @version     1.0
 * @brief       Manageloop of csr-server with epoll
 */
#pragma once

#include <functional>
#include <mutex>
#include <unordered_map>

#include "common/mainloop.h"
#include "common/macros.h"

namespace Csr {

class API NativeMainloop : public Mainloop {
public:
	NativeMainloop();
	virtual ~NativeMainloop();

	virtual void run(int timeout) override;
	virtual void addEventSource(
		int fd, Mainloop::Event event, Mainloop::Callback &&callback) override;
	virtual void removeEventSource(int fd) override;

private:
	void dispatch(int timeout);
	static uint32_t convertFlags(Mainloop::Event events);
	static Mainloop::Event convertFlags(uint32_t events);

	bool m_isTimedOut;
	int m_pollfd;
	mutable std::mutex m_mutex;
	std::unordered_map<int, Mainloop::Callback> m_callbacks;

	constexpr static size_t MAX_EPOLL_EVENTS = 32;
};

}
