/*
 *  Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License
 */
#include "service/app-dirs.h"

#include <string>
#include <mutex>

namespace {

inline std::regex _regex(const char *str)
{
	return std::regex(str, std::regex_constants::extended);
}

}

namespace Csr {

std::vector<std::regex> AppDirs::m_regex;

const std::vector<std::regex> &AppDirs::get()
{
	return AppDirs::m_regex;
}

void AppDirs::init()
{
	static std::once_flag f;

	std::call_once(f, []() { AppDirs::initOnce(); });
}

void AppDirs::initOnce()
{
#define __INS_REGEX(str) AppDirs::m_regex.emplace_back(_regex(str))

	// internal storages
	__INS_REGEX("^(" TZ_SYS_RW_APP "/([^/]+))"); // $TZ_SYS_RW_APP/{pkgid}/
	__INS_REGEX("^(" TZ_SYS_RO_APP "/([^/]+))"); // $TZ_SYS_RO_APP/{pkgid}/
	// (linked prefix)/home/{user}/(appdir)/{pkgid}/
	__INS_REGEX("^(/home/([^/]+)/apps_rw/([^/]+))");
	__INS_REGEX("^(/opt/usr/home/([^/]+)/apps_rw/([^/]+))");

	// external storages
	// (linked prefix)/sdcard/app2sd/{pkgid}/
	// (linked prefix)/sdcard/app2sd/{user}/{pkgid}/
	// (linked prefix)/sdcard/apps/{user}/apps_rw/{pkgid}/
	__INS_REGEX("^(/sdcard/app2sd/([^/]+))");
	__INS_REGEX("^(/sdcard/app2sd/([^/]+)/([^/]+))");
	__INS_REGEX("^(/sdcard/apps/([^/]+)/apps_rw/([^/]+))");
	__INS_REGEX("^(" TZ_SYS_STORAGE "/sdcard/app2sd/([^/]+))");
	__INS_REGEX("^(" TZ_SYS_STORAGE "/sdcard/app2sd/([^/]+)/([^/]+))");
	__INS_REGEX("^(" TZ_SYS_STORAGE "/sdcard/apps/([^/]+)/apps_rw/([^/]+))");

#undef __INS_REGEX
}

}
