/*
 *  Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License
 */
/*
 * @file       iloader.h
 * @author     Kyungwook Tak (k.tak@samsung.com)
 * @version    1.0
 * @brief      engine loader abstract class
 */
#pragma once

#include <string>

namespace Csr {

class ILoader {
public:
	void reset(const std::string &enginePath, const std::string &roResDir,
			   const std::string &rwWorkingDir)
	{
		this->deinit();
		this->init(enginePath, roResDir, rwWorkingDir);
	}

	virtual std::string getErrorString(int) = 0;

protected:
	virtual ~ILoader() = default;

	virtual void deinit() = 0;
	virtual void init(const std::string &enginePath, const std::string &roResDir,
					  const std::string &rwWorkingDir) = 0;

	virtual void toException(int ee, bool internalErrorToString = true);
};

}
