/*
 *  Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License
 */
/*
 * @file       wp-loader.h
 * @author     Sangsu Choi (sangsu.choi@samsung.com)
 * @version    1.0
 * @brief
 */
#pragma once

#include <memory>
#include <vector>
#include <string>
#include <ctime>

#include <csre-web-protection-types.h>
#include <csre-web-protection-engine-info.h>

#include "service/iloader.h"

namespace Csr {

class WpLoader : public ILoader {
public:
	WpLoader(const std::string &enginePath, const std::string &roResDir,
			 const std::string &rwWorkingDir);
	virtual ~WpLoader();

	void contextCreate(csre_wp_context_h &);
	void contextDestroy(csre_wp_context_h);
	void checkUrl(csre_wp_context_h handle, const std::string &,
				 csre_wp_check_result_h *);
	void getRiskLevel(csre_wp_check_result_h, csre_wp_risk_level_e *);
	void getDetailedUrl(csre_wp_check_result_h, std::string &);
	void getEngineApiVersion(csre_wp_context_h, std::string &);
	void getEngineVendor(csre_wp_context_h, std::string &);
	void getEngineName(csre_wp_context_h, std::string &);
	void getEngineVersion(csre_wp_context_h, std::string &);
	void getEngineDataVersion(csre_wp_context_h, std::string &);
	time_t getEngineLatestUpdateTime(csre_wp_context_h);
	void getEngineActivated(csre_wp_context_h, csre_wp_activated_e *);
	void getEngineVendorLogo(csre_wp_context_h, std::vector<unsigned char> &);

	virtual std::string getErrorString(int) override;

private:
	using FpGlobalInit = int(*)(const char *, const char *);
	using FpGlobalDeinit = int(*)();
	using FpContextCreate = int(*)(csre_wp_context_h *);
	using FpContextDestroy = int(*)(csre_wp_context_h);
	using FpCheckUrl = int(*)(csre_wp_context_h , const char *,
							  csre_wp_check_result_h *);
	using FpGetRiskLevel = int(*)(csre_wp_check_result_h, csre_wp_risk_level_e *);
	using FPGetDetailedUrl = int(*)(csre_wp_check_result_h, const char **);
	using FpGetErrorString = int(*)(int, const char **);
	using FpGetEngineApiVersion = int(*)(csre_wp_context_h, const char **);
	using FpGetEngineVendor = int(*)(csre_wp_context_h, const char **);
	using FpGetEngineName = int(*)(csre_wp_context_h, const char **);
	using FpGetEngineVersion = int(*)(csre_wp_context_h, const char **);
	using FpGetEngineDataVersion = int(*)(csre_wp_context_h, const char **);
	using FpGetEngineLatestUpdateTime = int(*)(csre_wp_context_h, time_t *);
	using FpGetEngineActivated = int(*)(csre_wp_context_h, csre_wp_activated_e *);
	using FpGetEngineVendorLogo = int(*)(csre_wp_context_h, unsigned char **,
										 unsigned int *);

	struct PluginContext {
		PluginContext() {}
		virtual ~PluginContext() {}

		void *dlhandle = nullptr;

		FpGlobalInit fpGlobalInit = nullptr;
		FpGlobalDeinit fpGlobalDeinit = nullptr;
		FpContextCreate fpContextCreate = nullptr;
		FpContextDestroy fpContextDestroy = nullptr;
		FpCheckUrl fpCheckUrl = nullptr;
		FpGetRiskLevel fpGetRiskLevel = nullptr;
		FPGetDetailedUrl fpGetDetailedUrl = nullptr;
		FpGetErrorString fpGetErrorString = nullptr;
		FpGetEngineApiVersion fpGetEngineApiVersion = nullptr;
		FpGetEngineVendor fpGetEngineVendor = nullptr;
		FpGetEngineName fpGetEngineName = nullptr;
		FpGetEngineVersion fpGetEngineVersion = nullptr;
		FpGetEngineDataVersion fpGetEngineDataVersion = nullptr;
		FpGetEngineLatestUpdateTime fpGetEngineLatestUpdateTime = nullptr;
		FpGetEngineActivated fpGetEngineActivated = nullptr;
		FpGetEngineVendorLogo fpGetEngineVendorLogo = nullptr;
	};

	virtual void init(const std::string &, const std::string &, const std::string &) override;
	virtual void deinit(void) override;

	void checkEngineActivated(csre_wp_context_h);

	PluginContext m_pc;
};

class WpEngineContext {
public:
	WpEngineContext(const std::shared_ptr<WpLoader> &);
	~WpEngineContext();
	csre_wp_context_h &get(void);

private:
	std::shared_ptr<WpLoader> m_loader;
	csre_wp_context_h m_context;
};

}
