/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
#pragma once

#include <unordered_map>
#include <memory>
#include <Elementary.h>

#include "common/mainloop.h"

namespace Csr {
namespace Ui {

class EcoreMainloop : public Mainloop {
public:
	EcoreMainloop();
	virtual ~EcoreMainloop();

	virtual void run(int timeout) override;

	virtual void addEventSource(
		int fd, Mainloop::Event event, Mainloop::Callback &&callback) override;
	virtual void removeEventSource(int fd) override;

private:
	struct EventSource {
		Mainloop::Callback callback;
		Ecore_Fd_Handler *handler;
	};

	void dispatch(int timeout);

	static Ecore_Fd_Handler_Flags convertFlags(Mainloop::Event events);
	static Mainloop::Event convertFlags(Ecore_Fd_Handler *handler);

	static Eina_Bool ecoreFdCallback(void *data, Ecore_Fd_Handler *handler);
	static Eina_Bool ecoreTimeoutCb(void *data);

	std::unordered_map<int, std::unique_ptr<EventSource>> m_sources;

	bool m_isExitCalled;
	Ecore_Timer *m_timer;
};

} // namespace Ui
} // namespace Csr
